pub struct ForeignKeyInfo {
pub constraint_name: String,
pub column: String,
pub foreign_table: String,
pub foreign_column: String,
pub on_update: Option<String>,
pub on_delete: Option<String>,
}Expand description
A foreign key constraint.
Fields
constraint_name: StringThe constraint name.
column: StringThe column on the referencing (child) table.
foreign_table: StringThe referenced (parent) table name.
foreign_column: StringThe referenced column in the parent table.
on_update: Option<String>Referential action on UPDATE of parent row (CASCADE, SET NULL, etc.).
None when the backend does not surface this information.
on_delete: Option<String>Referential action on DELETE of parent row.
None when the backend does not surface this information.